module Hcheck
  module Checks
    # ping check module
    # implements status
    # include ping check dependencies
    # returns ok only if the response code is 2** or 3**
    module Ping
      # @config { url }
      def status(config)
        url = URI.parse(config[:url])
        request = build_request(url)

        res = request.request_head(url.path)

        ok_responses = [Net::HTTPSuccess, Net::HTTPInformation, Net::HTTPMovedPermanently]

        fail_with(res, url) unless ok_responses.include?(res.class)
      end

      def self.included(_base)
        require 'net/http'
      end

      def build_request(url)
        req = Net::HTTP.new(url.host, url.port)
        req.use_ssl = true if url.scheme == 'https'
        req.read_timeout = 5 # seconds

        url.path = '/' if url.path.empty?
        req
      end

      def fail_with(response, url)
        raise Hcheck::Errors::HTTPError,
              [response.class, response.code, response.message].join(' ') + " from #{url}"
      end
    end
  end
end
