# frozen_string_literal: true

module Hcheck
  module Errors
    # Hcheck standard error class
    class HcheckError < StandardError
      MSG = 'Hcheck standard error'

      def initialize(msg = nil)
        message = msg || self.class::MSG
        Hcheck.logger.error message
        super(message)
      end
    end

    # Invalid auth token, when hcheck secure enabled
    class InvalidAuthentication < HcheckError
      MSG = 'Invalid authenticity token!'
    end

    # Incomplete auth setup, auth token not setup, when hcheck secure enabled
    class IncompleteAuthSetup < HcheckError
      MSG = 'Incomplete auth setup in HCheck server'
    end

    # Configuration related error
    class ConfigurationError < HcheckError
      MSG = 'Hcheck configuration cannot not be found or read'

      def initialize(err)
        super("#{MSG}\n#{err.class}\n#{err.message}")
      end
    end

    # HTTP related error
    class HTTPError < HcheckError
      def initialize(msg)
        super("Couldn't get a successful response code. #{msg}")
      end
    end
  end
end
